import express, { Request, Response } from "express";
import PermissionHelper from "../../../helpers/permissionHelper";
import {
  createApi,
  deleteApi,
  getAllApis,
  getApiById,
  getApiPermissions,
  updateApi,
  updateApiPermissions,
} from "../../../controller/admin/user/apiController";

var router = express.Router({ mergeParams: true });

router.get("/", async (req: Request, res: Response) => {
  await getAllApis(req, res);
});

router.get("/:id", async (req: Request, res: Response) => {
  await getApiById(req, res);
});

router.get("/:id/permissions", async (req: Request, res: Response) => {
  await getApiPermissions(req, res);
});

router.post(
  "/",
  PermissionHelper.passCheckMiddleware("create", "user", "webapi"),
  async (req: Request, res: Response) => {
    await createApi(req, res);
  }
);

router.patch(
  "/:id",
  PermissionHelper.passCheckMiddleware("update", "user", "webapi"),
  async (req: Request, res: Response) => {
    await updateApi(req, res);
  }
);

router.patch(
  "/:id/permissions",
  PermissionHelper.passCheckMiddleware("admin", "user", "webapi"),
  async (req: Request, res: Response) => {
    await updateApiPermissions(req, res);
  }
);

router.delete(
  "/:id",
  PermissionHelper.passCheckMiddleware("delete", "user", "webapi"),
  async (req: Request, res: Response) => {
    await deleteApi(req, res);
  }
);

export default router;
